arch_copy_from_user

Function arch_copy_from_user 

pub unsafe fn arch_copy_from_user(
    dst: *mut c_void,
    src: *const c_void,
    len: usize,
) -> Result<(), Status>
Copies len bytes from user memory at src into kernel memory at dst.

Safety

Caller must ensure dst points to at least len bytes of valid memory and src is a user pointer.