pub unsafe fn arch_copy_to_user(
dst: *mut c_void,
src: *const c_void,
len: usize,
) -> Result<(), Status>Expand description
Copies len bytes from kernel memory at src into user memory at dst.
Safety
Caller must ensure src points to at least len bytes of valid memory
and dst is a user pointer.